copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
ComponentAdapter copyWith({String? name, WasmInput? wasm}) =>
ComponentAdapter(name: name ?? this.name, wasm: wasm ?? this.wasm);
Returns a new instance by overriding the values passed as arguments
ComponentAdapter copyWith({String? name, WasmInput? wasm}) =>
ComponentAdapter(name: name ?? this.name, wasm: wasm ?? this.wasm);