copyWith method
Returns a new instance by overriding the values passed as arguments
Implementation
ModuleExport copyWith({String? name, ExternType? type}) =>
ModuleExport(name: name ?? this.name, type: type ?? this.type);
Returns a new instance by overriding the values passed as arguments
ModuleExport copyWith({String? name, ExternType? type}) =>
ModuleExport(name: name ?? this.name, type: type ?? this.type);